{
  pkgs,
  nixpkgs,
  nixpkgs-unstable,
  nixos-hardware,
  ...
}: {
  imports = [
    nixos-hardware.nixosModules.lenovo-thinkpad-x270
  ];

  system.stateVersion = "23.11";

  time.timeZone = "Europe/Berlin";
  i18n.defaultLocale = "en_US.UTF-8";

  boot = {
    supportedFilesystems = ["bcachefs"];
    kernelPackages = pkgs.linuxPackages_latest; # TODO: remove when default kernel hits 6.7

    loader = {
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };
  };

  networking = {
    networkmanager.enable = true;
    nameservers = ["1.1.1.1"];
  };

  nix = {
    registry = {
      nixpkgs.flake = nixpkgs;
      nixpkgs-unstable.flake = nixpkgs-unstable;
    };

    settings = {
      auto-optimise-store = true;
      trusted-users = ["root" "buffet"];
    };

    gc = {
      automatic = true;
      dates = "weekly";
      options = "--delete-older-than 30d";
    };

    extraOptions = ''
      experimental-features = nix-command flakes
    '';
  };
}
